@@ -23,16 +23,16 @@ all
 </preinstall>
 
 <install_package_names>
-winehq-staging
+wine
 </install_package_names>
 
 
 <postinstall>
-/usr/share/packageinstaller-pkglist/run_winecfg.sh
+
 </postinstall>
 
 
 <uninstall_package_names>
-winehq-staging
+wine
 </uninstall_package_names>
 </app>
